@@ -88,6 +88,24 @@ class DatasetManager:
         return self.loadDatasetFromFiles(path_base+"_t1.nii", path_base+"_t2.nii", path_base+"_m0.nii",
                                          mprage_file, tse_file, registered_mprage_file, registered_tse_file)
 
+    def fetchSingleSeriesFromAzure(self, subject, scanner, set, series, extension=".nii"):
+        if(self.connectionString == None or self.container == None):
+            print("Dataset Manager Azure connection string or container not set.")
+            return None
+        else:
+            blob_service_client = BlobServiceClient.from_connection_string(self.connectionString)
+            container_name = self.container
+            container_client = blob_service_client.get_container_client(container_name)
+            uri_base = subject+"/"+scanner+"/"+set
+            path_dir = self.localDataRootDir+"/"+subject+"/"+scanner
+            path_base = path_dir+"/"+set
+            print(path_base)
+            Path(path_dir).mkdir( parents=True, exist_ok=True )
+            container_client = blob_service_client.get_container_client(container= container_name) 
+            with open(path_base+"_"+series+extension, "wb") as download_file:
+                download_file.write(container_client.download_blob(uri_base+"_"+series+extension).readall())
+            return self.loadSingleSeries(subject, scanner, set, series, extension)
+
     def fetchSetFromAzure(self, subject, scanner, set, includeMPRAGE=False, includeTSE=False):
         if(self.connectionString == None or self.container == None):
             print("Dataset Manager Azure connection string or container not set.")
